illustrateLLN(Distr = Norm(),n = c(1,3,5,10,25,50,100,500,1000,10000),
m = 50, step = 1, sleep = 0, withConf = TRUE,
withCover = (length(n)"UnivariateDistribution":
distribution of the summandsCauchy instead: median)
be drawn?par);
line width of the confidence bandspar);
line type of the confidence bandspar);
line width of the confidence bandspar);
line type of the confidence bandscex
to be used for empirical coverages; as in
parcex
to be used for the legend as in
parmatplot,
matlines, ablineltyillustrateLLN generates a sequence of plots.
Any parameters of plot.default may be passed on to this particular
plot method.
There are default main titles as well as xlab and ylab
annotations.
In all title arguments, the following patterns are substituted:
"%C"x}
"%P"x in form of a comma-separated list of
"%Q"x in form of a comma-separated list of
"%N"x in form of a comma-separated list
"%A"x}
"%D""%X"illustrateLLN(Distr = Unif())
illustrateLLN(Distr = Pois(lambda = 2))
illustrateLLN(Distr = Pois(lambda = 2)+Unif())
illustrateLLN(Td(3), m = 50, col.Eline = "green", lwd = 2, cex = 0.6, main =
"My LLN %C%Q", sub = "generated %D")
illustrateLLN(Td(3), m = 50, CLTorCheb = "Chebyshev")
illustrateLLN(Td(3), m = 50, CLTorCheb = "Chebyshev", coverage = 0.75)Run the code above in your browser using DataLab